@@ -8,13 +8,16 @@ from petisco.persistence.sqlalchemy.sqlalchemy_persistence import SqlAlchemyPers
 
 
 @contextmanager
-def session_scope():
+def session_scope(source: str):
     """Provide a transactional scope around a series of operations."""
-    transactional_scope = SqlAlchemyPersistence.get_instance().session()
+    transactional_scope = SqlAlchemyPersistence.get_instance().sources[source][
+        "session"
+    ]()
     try:
         yield transactional_scope
         transactional_scope.commit()
-    except OperationalError:
+    except OperationalError as e:
+        print(e)
         transactional_scope.rollback()
         raise SqlAlchemyOperationalDatabaseError
     except Exception as e:
